# Fax in strax

[![Build Status](https://travis-ci.org/XENONnT/WFSim.svg?branch=master)](https://travis-ci.org/XENONnT/WFSim)
[![Coverage Status](https://coveralls.io/repos/github/XENONnT/WFSim/badge.svg?branch=ci_testing)](https://coveralls.io/github/XENONnT/WFSim?branch=ci_testing)
[![Pytest](https://github.com/XENONnT/WFSim/workflows/Pytest/badge.svg?branch=master)](https://github.com/XENONnT/WFSim/actions?query=workflow%3APytest)
[![CodeFactor](https://www.codefactor.io/repository/github/xenonnt/wfsim/badge)](https://www.codefactor.io/repository/github/xenonnt/wfsim)

Here are the files needed to run the waveform simulator fax and give output in the same formats as used by strax.

## Installation

Clone the repository and let pip install it for you
```
git clone https://github.com/XENONnT/WFSim
pip install -e ./WFSim
```

Or on midway
```
/project2/lgrandi/xenonnt/development/xnt_env
git clone https://github.com/XENONnT/WFSim
pip install -e ./WFSim --user
```

## Usage
In the notebook folder there is a short test notebook showing basic usage.
